#
# spec file for package ecj
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global qualifier R-4.4-201406061215
Name:           ecj
Version:        4.4.0
Release:        lp150.2.10
Summary:        Eclipse Compiler for Java
License:        EPL-1.0
Group:          Development/Languages/Java
Url:            http://www.eclipse.org
Source0:        http://download.eclipse.org/eclipse/downloads/drops4/%{qualifier}/%{name}src-4.4.jar
Source1:        ecj.sh.in
# Use ECJ for GCJ
# cvs -d:pserver:anonymous@sourceware.org:/cvs/rhug \
# export -D 2009-09-28 eclipse-gcj
# tar cjf ecj-gcj.tar.bz2 eclipse-gcj
Source2:        %{name}-gcj.tar.bz2
#Patched from http://central.maven.org/maven2/org/eclipse/jdt/core/compiler/ecj/4.4/ecj-4.4.pom
# No dependencies are needed for ecj, dependencies are for using of jdt.core which makes no sense outside of eclipse
Source3:        ecj-4.4.pom
Source4:        ecj.1
# http://git.eclipse.org/c/jdt/eclipse.jdt.core.git/plain/org.eclipse.jdt.core/scripts/binary/META-INF/MANIFEST.MF
Source5:        META-INF/MANIFEST.MF
# Always generate debug info when building RPMs (Andrew Haley)
Patch0:         %{name}-rpmdebuginfo.patch
# build.xml fails to include a necessary .props file in the built ecj.jar
Patch1:         %{name}-include-props.patch
# Patches Source2 for compatibility with newer ecj
Patch2:         eclipse-gcj-compat4.2.1.patch
Patch3:         eclipse-gcj-nodummysymbol.patch
BuildRequires:  ant
BuildRequires:  gzip
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  unzip
Conflicts:      ecj-bootstrap
Provides:       eclipse-ecj = %{version}-%{release}
Obsoletes:      eclipse-ecj < 3.4.2-4
BuildArch:      noarch

%description
ECJ is the Java bytecode compiler of the Eclipse Platform.  It is also known as
the JDT Core batch compiler.

%prep
%setup -q -c
%patch0 -p1
%patch1 -b .sav

sed -i -e 's|debuglevel=\"lines,source\"|debug=\"yes\"|g' build.xml
sed -i -e "s/Xlint:none/Xlint:none -encoding cp1252/g" build.xml

%if 0%{?suse_version} < 1200
sed -i -e 's|source=\"1.6\"|source=\"1.5\"|g' build.xml
sed -i -e 's|target=\"1.6\"|target=\"1.5\"|g' build.xml
%endif

cp %{SOURCE3} pom.xml
mkdir -p scripts/binary/META-INF/
cp %{SOURCE5} scripts/binary/META-INF/MANIFEST.MF

# Use ECJ for GCJ's bytecode compiler
tar jxf %{SOURCE2}
mv eclipse-gcj/org/eclipse/jdt/internal/compiler/batch/GCCMain.java \
  org/eclipse/jdt/internal/compiler/batch/
%patch2 -p1
%patch3 -p1
cat eclipse-gcj/gcc.properties >> \
  org/eclipse/jdt/internal/compiler/batch/messages.properties
rm -rf eclipse-gcj

# Remove bits of JDT Core we don't want to build
rm -r org/eclipse/jdt/internal/compiler/tool
rm -r org/eclipse/jdt/internal/compiler/apt
rm -f org/eclipse/jdt/core/BuildJarIndex.java

# JDTCompilerAdapter isn't used by the batch compiler
rm -f org/eclipse/jdt/core/JDTCompilerAdapter.java
cp %{SOURCE4} ecj.1

%build
ant
gzip ecj.1

%install
mkdir -p %{buildroot}%{_javadir}
install -m0644 ecj.jar %{buildroot}%{_javadir}/%{name}.jar
pushd %{buildroot}%{_javadir}
ln -s %{name}.jar eclipse-%{name}.jar
ln -s %{name}.jar jdtcore.jar
popd

# Install the ecj wrapper script
install -p -D -m0755 %{SOURCE1} %{buildroot}%{_bindir}/ecj
sed --in-place "s:@JAVADIR@:%{_javadir}:" %{buildroot}%{_bindir}/ecj

# Install manpage
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 -p ecj.1.gz %{buildroot}%{_mandir}/man1/ecj.1.gz

# poms
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml \
    %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom

%add_maven_depmap -a "org.eclipse.tycho:org.eclipse.jdt.core,org.eclipse.jdt:core,org.eclipse.jdt:org.eclipse.jdt.core" JPP-%{name}.pom %{name}.jar

%files -f .mfiles
%doc about.html
%{_mavenpomdir}/JPP-%{name}.pom
%{_bindir}/%{name}
%{_javadir}/%{name}.jar
%{_javadir}/eclipse-%{name}.jar
%{_javadir}/jdtcore.jar
%{_mandir}/man1/ecj.1%{ext_man}

%changelog
* Mon Sep 18 2017 fstrba@suse.com
- Don't build against the java-bootstrap package; it is gone
* Fri May 19 2017 tchvatal@suse.com
- Fix build with javapacakges-tools
* Thu Sep 10 2015 tchvatal@suse.com
- Fix cycles on Leap which is 1315 same as SLE.
- Sort deps with spec-cleaner
* Fri Sep 19 2014 dmacvicar@suse.de
- avoid cycles in Factory with Java 8
* Thu Sep 18 2014 dmacvicar@suse.de
- Remove upstream git URL for MANIFEST.MF as it is not
  versioned. File will change and Factory bots will
  complain.
* Thu Sep 18 2014 dmacvicar@suse.de
- restore bootstrap dependencies
- Restored patches and GCJ Main, as they are used
  to bootstrap other packages.
  * eclipse-gcj-compat4.2.1.patch
  * eclipse-gcj-nodummysymbol.patch
- Removed obsolete ecj-native, as old SUSE package did
  not had it and no package provides it
* Wed Sep 17 2014 dmacvicar@suse.de
- clean spec file
* Mon Sep 15 2014 dmacvicar@suse.de
- export NO_BRP_CHECK_BYTECODE_VERSION
* Mon Sep 15 2014 dmacvicar@suse.de
- Update to ecj 4.2.1 (expected by tomcat 7.0.55+)
- Sync with Fedora ecj-4.4
- Drop gcj patches
  * eclipse-gcj-nodummysymbol.patch
- Drop obsolete patches
  * ecj-generatedebuginfo.patch : now done in spec
  * eclipse-gcj-compat4.2.1.patch
  * ecj-defaultto1.5.patch : we can use 1.6
* Wed Sep  3 2014 tchvatal@suse.com
- Spec-cleaner
- BuildIgnore java-devel pkgs to avoid conflicts
* Wed Sep  3 2014 coolo@suse.com
- on 13.2 and Factory build against bootstrap java
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri May 31 2013 varkoly@suse.com
- Fix the spec to avoid fileconflicts with ecj-bootstrap
* Mon Jan 21 2013 mvyskocil@suse.com
- Update to ecj 4.2.1 (expected by tomcat 7.0.34+)
  (no changelog provided, but it's normal for eclipse)
- sync with fedora 4.2.1-3
  * ecj-defaultto1.5.patch - change the default -source to 1.5 to
    match gcc-java capabilities
  * ecj-generatedebuginfo.patch - generate debug info for java sources
  * ecj-include-props.patch - package .props files too
  * ecj-rpmdebuginfo.patch - hack, force debuginfo to be created when
    RPM_BUILD_ROOT variable is defined
  * eclipse-gcj-compat4.2.1.patch - disable all expected warning
  * eclipse-gcj-nodummysymbol.patch - don't generate dummy entry in jars
  * eclipse-jpackage-changelog.txt
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Thu Nov 22 2007 anosek@suse.cz
- new package, initial version 3.3
